@@ -1,5 +1,5 @@
 # Copyright (C) 2005, 2006, 2007 Aaron Bentley <aaron@aaronbentley.com>
-# Copyright (C) 2005, 2006 Canonical Limited.
+# Copyright (C) 2005, 2006, 2011 Canonical Limited.
 # Copyright (C) 2006 Michael Ellerman.
 #
 #    This program is free software; you can redistribute it and/or modify
@@ -379,15 +379,37 @@ class cmd_zap(BzrToolsCommand):
 
     If --branch is specified, the branch will be deleted too, but only if the
     the branch has no new commits (relative to its parent).
+
+    If bzr-pipeline is also installed, the --store option will store changes
+    in the branch before deleting the tree.  To restore the changes, do::
+
+      bzr checkout --lightweight $BRANCH $CHECKOUT
+      bzr switch-pipe -d $CHECKOUT `bzr nick -d $CHECKOUT`
     """
     takes_options = [Option("branch", help="Remove associated branch from"
                                            " repository."),
-                     Option('force', help='Delete tree even if contents are'
-                     ' modified.')]
+                     RegistryOption('change_policy',
+                                    'How to handle changed files',
+                                    lazy_registry =
+                                    ('bzrlib.plugins.bzrtools.zap',
+                                        'change_policy_registry'),
+                                    value_switches=True,
+                                    enum_switch=False)]
     takes_args = ["checkout"]
-    def run(self, checkout, branch=False, force=False):
-        from zap import zap
-        return zap(checkout, remove_branch=branch, allow_modified=force)
+    def run(self, checkout, branch=False, change_policy=None):
+        from zap import (
+            change_policy_registry,
+            StoreChanges,
+            zap,
+        )
+        if change_policy is None:
+            change_policy = change_policy_registry.get()
+        if change_policy is StoreChanges:
+            try:
+                import bzrlib.plugins.pipeline
+            except ImportError:
+                raise BzrCommandError('--store requires bzr-pipeline.')
+        return zap(checkout, remove_branch=branch, policy=change_policy)
 
 
 class cmd_cbranch(BzrToolsCommand):
