@@ -20,7 +20,6 @@ import time
 
 from bzrlib.branch import Branch
 from bzrlib.errors import BzrCommandError, NoSuchRevision
-from bzrlib.deprecated_graph import node_distances, select_farthest
 from bzrlib.revision import NULL_REVISION
 
 from bzrtools import short_committer
@@ -38,6 +37,77 @@ from dotgraph import (
     )
 
 
+def max_distance(node, ancestors, distances, root_descendants):
+    """Calculate the max distance to an ancestor.
+    Return None if not all possible ancestors have known distances"""
+    best = None
+    if node in distances:
+        best = distances[node]
+    for ancestor in ancestors[node]:
+        # skip ancestors we will never traverse:
+        if root_descendants is not None and ancestor not in root_descendants:
+            continue
+        # An ancestor which is not listed in ancestors will never be in
+        # distances, so we pretend it never existed.
+        if ancestor not in ancestors:
+            continue
+        if ancestor not in distances:
+            return None
+        if best is None or distances[ancestor]+1 > best:
+            best = distances[ancestor] + 1
+    return best
+
+
+def node_distances(graph, ancestors, start, root_descendants=None):
+    """Produce a list of nodes, sorted by distance from a start node.
+    This is an algorithm devised by Aaron Bentley, because applying Dijkstra
+    backwards seemed too complicated.
+
+    For each node, we walk its descendants.  If all the descendant's ancestors
+    have a max-distance-to-start, (excluding ones that can never reach start),
+    we calculate their max-distance-to-start, and schedule their descendants.
+
+    So when a node's last parent acquires a distance, it will acquire a
+    distance on the next iteration.
+
+    Once we know the max distances for all nodes, we can return a list sorted
+    by distance, farthest first.
+    """
+    distances = {start: 0}
+    lines = set([start])
+    while len(lines) > 0:
+        new_lines = set()
+        for line in lines:
+            line_descendants = graph[line]
+            for descendant in line_descendants:
+                distance = max_distance(descendant, ancestors, distances,
+                                        root_descendants)
+                if distance is None:
+                    continue
+                distances[descendant] = distance
+                new_lines.add(descendant)
+        lines = new_lines
+    return distances
+
+
+def nodes_by_distance(distances):
+    """Return a list of nodes sorted by distance"""
+    def by_distance(n):
+        return distances[n],n
+
+    node_list = distances.keys()
+    node_list.sort(key=by_distance, reverse=True)
+    return node_list
+
+
+def select_farthest(distances, common):
+    """Return the farthest common node, or None if no node qualifies."""
+    node_list = nodes_by_distance(distances)
+    for node in node_list:
+        if node in common:
+            return node
+
+
 mail_map = {'aaron.bentley@utoronto.ca'     : 'Aaron Bentley',
             'abentley@panoramicfeedback.com': 'Aaron Bentley',
             'abentley@lappy'                : 'Aaron Bentley',
