@@ -5,10 +5,17 @@ from unittest import makeSuite
 from bzrlib import branch, osutils, workingtree
 from bzrlib.config import LocationConfig
 from bzrlib.transport import get_transport
-from bzrlib.tests import TestCaseWithTransport, HardlinkFeature
+from bzrlib.tests import (
+    HardlinkFeature,
+    ModuleAvailableFeature,
+    TestCaseWithTransport,
+    )
 from bzrlib.plugins.bzrtools import command
 
 
+LzmaFeature = ModuleAvailableFeature("lzma")
+
+
 class TestBzrTools(TestCaseWithTransport):
 
     def setUp(self):
@@ -88,10 +95,10 @@ class TestBzrTools(TestCaseWithTransport):
         checkout.add('file')
         self.run_bzr_error(('This checkout has uncommitted changes',),
                            'zap checkout')
-        self.failUnlessExists('checkout')
+        self.assertPathExists('checkout')
         self.run_bzr('zap checkout --force')
-        self.failIfExists('checkout')
-        self.failUnlessExists('source')
+        self.assertPathDoesNotExist('checkout')
+        self.assertPathExists('source')
 
     def test_zap_branch(self):
         self.run_bzr('init source')
@@ -133,7 +140,7 @@ class TestBzrTools(TestCaseWithTransport):
         self.run_bzr('init ../import')
         os.chdir('../import')
         self.run_bzr('import ../source-0.1.tar.gz')
-        self.failUnlessExists('src/myfile')
+        self.assertPathExists('src/myfile')
         result = self.run_bzr('import ../source-0.1.tar.gz', retcode=3)[1]
         self.assertContainsRe(result, 'Working tree has uncommitted changes')
         self.run_bzr('commit -m commit')
@@ -141,13 +148,31 @@ class TestBzrTools(TestCaseWithTransport):
         os.chdir('..')
         self.run_bzr('init import2')
         self.run_bzr('import source-0.1.tar.gz import2')
-        self.failUnlessExists('import2/src/myfile')
+        self.assertPathExists('import2/src/myfile')
         self.run_bzr('import source-0.1.tar.gz import3')
-        self.failUnlessExists('import3/src/myfile')
+        self.assertPathExists('import3/src/myfile')
         self.run_bzr('import source-0.1.tar.bz2 import4')
-        self.failUnlessExists('import4/src/myfile')
+        self.assertPathExists('import4/src/myfile')
         self.run_bzr('import source-0.1 import5')
-        self.failUnlessExists('import5/src/myfile')
+        self.assertPathExists('import5/src/myfile')
+
+    def test_import_upstream_lzma(self):
+        self.requireFeature(LzmaFeature)
+        self.run_bzr('init source')
+        os.mkdir('source/src')
+        f = file('source/src/myfile', 'wb')
+        f.write('hello?')
+        f.close()
+        os.chdir('source')
+        self.run_bzr('add')
+        self.run_bzr('commit -m hello')
+        self.run_bzr('export ../source-0.1.tar.lzma')
+        self.run_bzr('export ../source-0.1.tar.xz')
+        os.chdir('..')
+        self.run_bzr('import source-0.1.tar.lzma import1')
+        self.assertPathExists('import1/src/myfile')
+        self.run_bzr('import source-0.1.tar.xz import2')
+        self.assertPathExists('import2/src/myfile')
 
     def test_cbranch(self):
         source = self.make_branch_and_tree('source')
