@@ -7,6 +7,7 @@ from bzrlib.plugins.bzrtools.hunk_selector import (
     UnshelveHunkSelector,
     )
 from bzrlib.plugins.bzrtools.errors import NoColor
+from bzrlib.plugins.bzrtools import command
 from bzrlib.plugins.bzrtools.command_classes import cmd_shelf1
 
 
@@ -32,6 +33,11 @@ class ShelfTests(bzrlib.tests.TestCaseWithTransport):
 +hello test world
  
 """
+    def setUp(self):
+        bzrlib.tests.TestCaseWithTransport.setUp(self)
+        command._testing = True
+        self.addCleanup(command._stop_testing)
+
     def _check_diff(self, diff=DIFF_1, filename='test_file'):
         old_tree = self.tree.basis_tree()
         old_tree.lock_read()
