@@ -19,6 +19,7 @@ import os
 from bzrlib.transform import TreeTransform
 from bzrlib.tests import TestCaseWithTransport, HardlinkFeature
 
+from bzrlib.plugins.bzrtools import command
 from bzrlib.plugins.bzrtools.link_tree import link_tree
 
 
@@ -73,9 +74,13 @@ class TestLinkTreeCommand(TestLinkTreeBase, TestCaseWithTransport):
 
     def test_link_tree(self):
         """Ensure the command works as intended"""
-        os.chdir('child')
-        self.parent_tree.unlock()
-        self.run_bzr('link-tree ../parent')
-        self.assertTrue(self.hardlinked())
-        # want teh addCleanup to work properly
-        self.parent_tree.lock_write()
+        command._testing = True
+        try:
+            os.chdir('child')
+            self.parent_tree.unlock()
+            self.run_bzr('link-tree ../parent')
+            self.assertTrue(self.hardlinked())
+            # want teh addCleanup to work properly
+            self.parent_tree.lock_write()
+        finally:
+            command._testing = False
