@@ -5,10 +5,17 @@ import tarfile
 import tempfile
 from unittest import makeSuite
 
-from bzrlib import osutils
+from bzrlib import (
+    osutils,
+    revision as _mod_revision,
+    transform
+    )
 from bzrlib.bzrdir import BzrDir
+from bzrlib.export import export
+from bzrlib.plugins.bzrtools import errors
 from bzrlib.plugins.bzrtools.upstream_import import (
     common_directory,
+    get_archive_type,
     import_archive,
     import_tar,
     import_zip,
@@ -16,7 +23,11 @@ from bzrlib.plugins.bzrtools.upstream_import import (
     top_path,
     ZipFileWrapper,
 )
-from bzrlib.tests import TestCaseInTempDir
+from bzrlib.tests import (
+    TestCaseInTempDir,
+    TestCaseWithTransport,
+    UnicodeFilenameFeature,
+    )
 
 
 def import_tar_broken(tree, tar_input):
@@ -246,5 +257,49 @@ class TestImport(TestCaseInTempDir):
         import_tar(tree, tar_file)
         # So long as it did not crash, that should be ok
 
+    def test_get_archive_type(self):
+        self.assertEqual(('tar', None), get_archive_type('foo.tar'))
+        self.assertEqual(('zip', None), get_archive_type('foo.zip'))
+        self.assertRaises(errors.NotArchiveType, get_archive_type, 'foo.gif')
+        self.assertEqual(('tar', 'gz'), get_archive_type('foo.tar.gz'))
+        self.assertRaises(errors.NotArchiveType, get_archive_type,
+                          'foo.zip.gz')
+        self.assertEqual(('tar', 'gz'), get_archive_type('foo.tgz'))
+        self.assertEqual(('tar', 'lzma'), get_archive_type('foo.tar.lzma'))
+        self.assertEqual(('tar', 'lzma'), get_archive_type('foo.tar.xz'))
+        self.assertEqual(('tar', 'bz2'), get_archive_type('foo.tar.bz2'))
+
+
+class TestWithStuff(TestCaseWithTransport):
+
+    def transform_to_tar(self, tt):
+        stream = StringIO()
+        export(tt.get_preview_tree(), root='', fileobj=stream, format='tar',
+               dest=None)
+        return stream
+
+    def get_empty_tt(self):
+        b = self.make_repository('foo')
+        null_tree = b.revision_tree(_mod_revision.NULL_REVISION)
+        tt = transform.TransformPreview(null_tree)
+        root = tt.new_directory('', transform.ROOT_PARENT, 'tree-root')
+        tt.fixup_new_roots()
+        self.addCleanup(tt.finalize)
+        return tt
+
+    def test_nonascii_paths(self):
+        self.requireFeature(UnicodeFilenameFeature)
+        tt = self.get_empty_tt()
+        encoded_file = tt.new_file(
+            u'\u1234file', tt.root, 'contents', 'new-file')
+        encoded_file = tt.new_file(
+            'other', tt.root, 'contents', 'other-file')
+        tarfile = self.transform_to_tar(tt)
+        tarfile.seek(0)
+        tree = self.make_branch_and_tree('bar')
+        import_tar(tree, tarfile)
+        self.assertPathExists(u'bar/\u1234file')
+
+
 def test_suite():
     return makeSuite(TestImport)
